@@ -20,6 +20,11 @@ class LessonType(Enum):
     FILE = 'file'
 
 
+class QuizType(Enum):
+    SUBMIT_SINGLE_QUESTION = 'submit_single_question'
+    SUBMIT_ALL = 'submit_all'
+
+
 @dataclass_json
 @dataclass
 class Lesson:
