@@ -640,7 +640,7 @@ class ProblemService:
                 problem.name = title
 
                 s = lines[statement_i[0] + 1].strip()
-                if not s.strip():
+                if not s.strip() and statement_i[0] < len(lines)-2:
                     s = lines[statement_i[0] + 2]
                 if s.startswith('[//]:'):
                     problem.preview = s
@@ -800,7 +800,9 @@ class ProblemService:
             print(f"Loaded {len(problem.testcases)} testcases")
 
         if not problem.testcases_sample and problem.testcases:
-            problem.testcases_sample = problem.testcases[:2]
+            # problem.testcases_sample = problem.testcases[:2]
+            for i in range(min(2, len(problem.testcases))):
+                problem.testcases[i].sample = True
 
         return problem
 
@@ -869,6 +871,7 @@ class ProblemService:
         problem.testcases = []
         if load_testcase:
             file_names = ["testcases_manual_stock.txt", "testcases_manual.txt", "testcases_stock.txt", "testcases.txt"]
+            file_names.append(problem_code + "_testcases.txt")
             input_set = set()
             for file_name in file_names:
                 testcase_file = os.path.abspath(os.path.join(problem_folder, file_name))
@@ -876,6 +879,7 @@ class ProblemService:
                 if not os.path.exists(testcase_file):
                     CLog.warn(f'`{testcase_file}` file not existed, skipping...')
                 else:
+                    CLog.info(f'`{testcase_file}` file FOUND, reading testcases...')
                     tests = read_ucode_testcases_from_file(testcase_file)
                     # print(f"reading testcases in file {testcase_file}: {len(tests)}")
                     for t in tests:
@@ -1150,30 +1154,51 @@ class ProblemService:
             t.sample = True
         testcases.extend(problem.stock_testcases)
         testcases.extend(problem.testcases)
+
         return testcases
 
 
-def convert_all_v1_to_new_format(base_folder):
+def convert_all_v1_to_new_format(src_folder, dest_folder=None, translations=[]):
     # problems = ProblemService.read_all_problems_v1(base_folder)
-    problems = ProblemService.read_all_problems_v1(base_folder, load_testcase=True, translations=["vi"])
+    problems = ProblemService.read_all_problems_v1(src_folder, load_testcase=True, translations=translations)
+
+    if not dest_folder:
+        dest_folder = src_folder + "_new"
 
     for folder, problem in problems:
         print(folder)
         base, folder_name = os.path.split(folder)
-
-        ProblemService.save(problem, base + "_new", problem_folder=folder_name, overwrite=True)
+        ProblemService.save(problem, dest_folder, problem_folder=folder_name, overwrite=True)
         print(problem.name)
         print(problem.testcase_format)
         print(len(problem.testcases))
         print(len(problem.testcases_sample))
 
 
-if __name__ == "__main__":
-    # base_folder = "D:\\projects\\ucode\\dsa-problems\\competitions\\hsg_thcs\\Thuc\\HaNoi2019"
-    # base_folder = "D:\\projects\\ucode\\weekly-algorithm-problems\\week10"
-    # base_folder = "D:\\projects\\ucode\\weekly-algorithm-problems\\competitions\\hsg-hn-2020"
+def change_testcases():
+    base_folder = "D:\\projects\\ucode\\basic_problems\\hour-of-code-round2\\p22_bicycle_race"
+    problem = ProblemService.load(base_folder, load_testcase=True)
+    print(len(problem.testcases))
+    new_testcases = []
+    import random
+    for testcase in random.choices(problem.testcases, k=8):
+        new_input=[]
+        for line in testcase.input.split():
+            new_input.extend(line.split())
+        new_test: TestCase = TestCase(input="\n".join(new_input), output=testcase.output)
+        new_testcases.append(new_test)
+    print(len(new_testcases))
+    problem.testcases = new_testcases
+    ProblemService.save(problem, base_folder + "_new")
 
-    # convert_all_v1_to_new_format(base_folder)
+
+if __name__ == "__main__":
+    # change_testcases()
+    # base_folder = "D:\\projects\\ucode\\dsa-problems\\competitions\\hsg_thcs\\Thuc\\HaNoi2019"
+    # base_folder = "D:\\projects\\ucode\\basic_problems\\hour-of-code-round2\\old"
+    base_folder = "D:\\projects\\ucode\\basic_problems\\hour-of-code-round3\\_old"
+
+    convert_all_v1_to_new_format(base_folder)
     # DsaProblem.create_problem('../../problems', 'Counting Sort 3', lang="en",
     #                           translations=['vi', 'ru'],
     #                           overwrite=True,
@@ -1186,22 +1211,22 @@ if __name__ == "__main__":
     #                       translations=['vi'], load_testcase=True)
 
     # folder = "../../../problems/p3_delrow"
-    folder = "D:\\projects\\ucode\\dsa-thematic-problems\\de_thi_hsg\\quan_ba_dinh_2020_2021_thcs\\cable"
+    # folder = "D:\\projects\\ucode\\dsa-thematic-problems\\de_thi_hsg\\quan_ba_dinh_2020_2021_thcs\\cable"
+    # # problem = ProblemService.load(folder, load_testcase=True)
     # problem = ProblemService.load(folder, load_testcase=True)
-    problem = ProblemService.load(folder, load_testcase=True)
-    # ProblemService.save(problem, "D:\\projects\\ucode\\_problem_dev", problem_folder="big_mod_py_", overwrite=True)
-    print(json.dumps(problem.solutions))
-    print(problem.name)
-    print("Input:")
-    print(problem.input_format)
-    print("Constraints:")
-    print(problem.constraints)
-    print("Output:")
-    print(problem.output_format)
-    print("Statement:")
-    print(problem.statement)
-
-    ProblemService.save(problem, base_folder="../../../problems/", problem_folder="_save", overwrite=True)
+    # # ProblemService.save(problem, "D:\\projects\\ucode\\_problem_dev", problem_folder="big_mod_py_", overwrite=True)
+    # print(json.dumps(problem.solutions))
+    # print(problem.name)
+    # print("Input:")
+    # print(problem.input_format)
+    # print("Constraints:")
+    # print(problem.constraints)
+    # print("Output:")
+    # print(problem.output_format)
+    # print("Statement:")
+    # print(problem.statement)
+    #
+    # ProblemService.save(problem, base_folder="../../../problems/", problem_folder="_save", overwrite=True)
     # print(problem.testcase_format)
     # print(len(problem.testcases))
     # print(len(problem.stock_testcases))
