@@ -5,10 +5,10 @@ import logging
 __author__ = 'ThucNC'
 
 import configparser
+import mimetypes
 import os
 from typing import List, Union
 
-import magic
 import requests
 from ucode.helpers.clog import CLog
 from ucode.helpers.config import Config
@@ -88,7 +88,7 @@ class UCode:
             file_name = os.path.basename(file_path)
             print(file_name)
             # content_type = "application/binary"
-            content_type = magic.from_file(file_path, mime=True)
+            content_type = mimetypes.guess_type(file_path)[0]
             print("Content-Type:", content_type)
             files = {'file': (file_name, f, content_type)}
             response = self.s.post(url, files=files, headers=self._headers)
@@ -294,7 +294,7 @@ class UCode:
 
         return question_ids
 
-    def upload_testcases(self, problem_id, testcases: List[TestCase], score=10):
+    def upload_testcases(self, problem_id, testcases: List[TestCase], score=10, sample_score=10):
         url = self.get_api_url(f"/question/{problem_id}/upload-testcases")
         testcase_data = []
         for i, testcase in enumerate(testcases):
@@ -303,7 +303,7 @@ class UCode:
                 "explanation": testcase.explanation,
                 "input": dos2unix(testcase.input),
                 "output": dos2unix(testcase.output),
-                "score": 0 if testcase.sample else score,
+                "score": sample_score if testcase.sample else score,
                 "is_sample": testcase.sample
             }
             testcase_data.append(t)
@@ -492,23 +492,25 @@ def create_public_problem():
 
 
 def create_problems_to_lesson_ucode_live():
-    base_folder = "D:\\projects\\ucode\\repl_backup\\ThucNguyen1\\pya1-1-lesson-8-9-10-for"
+    # base_folder = "D:\\projects\\ucode\\repl_backup\\ThucNguyen1\\python-102-11-lesson-5-6-turtle"
 
-    # base_folder = "D:\\projects\\ucode\\repl_backup\\itteacher-k1\\quiz5.1_list"
+    # base_folder = "/home/thanh/Ucode/basic-problems/problem_set_01"
+    # base_folder = "D:\\projects\\ucode\\basic_problems\\hoc_vong_2\\secondary-school\\hinh_chu_nhat"
+    base_folder = "D:\\projects\\ucode\\repl_backup\\py102-final-test"
     # base_folder = "D:\\projects\\ucode\\dsa-thematic-problems\\de_thi_hsg\\quan_ba_dinh_2020_2021_thcs_round2"
     # base_folder = "D:\\projects\\ucode\\weekly-algorithm-problems\\competitions\\hsg-hn-2020_new"
-
-    # D:\projects\ucode\weekly-algorithm-problems\week13
-    base_folder = "D:\\projects\\ucode\\repl_backup\\itteacher-k1\\quiz8_dict"
+    # base_folder = "D:\\projects\\ucode\\repl_backup\\itteacher-k1\\quiz9_turtle"
     # base_folder = "D:\\projects\\ucode\\dsa-thematic-problems\\de_thi_hsg\\hanoi_2020_2021_thcs"
     # base_folder = "D:\\projects\\ucode\\dsa-thematic-problems\\de_thi_hsg\\vinhphuc_2020_2021_thcs"
-    # base_folder = "D:\\projects\\ucode\\repl_backup\\intro2"
+    # base_folder = "D:\\projects\\ucode\\repl_backup\\intro3"
     # base_folder = "D:\\projects\\ucode\\dsa-problems\\competitions\\hsg_thcs\Thuc\HaNoi2019_new"
-    base_folder = "D:\\projects\\ucode\\weekly-algorithm-problems\\week13"
-    problems = ProblemService.read_all_problems_v1(base_folder, nested_folder=False, translations=['vi'])
-    # problems = ProblemService.read_all_problems(base_folder, nested_folder=False)
 
-    lesson_id = 5477
+    # problems = ProblemService.read_all_problems(base_folder, nested_folder=False)
+    problems = ProblemService.read_all_problems_v1(base_folder, nested_folder=False)
+
+    # problems = [(base_folder, ProblemService.load(base_folder))]
+
+    lesson_id = 5716
     ucode = UCode("prod")
     #
     # lesson_id = 4622
@@ -517,9 +519,9 @@ def create_problems_to_lesson_ucode_live():
     for i, (problem_folder, problem) in enumerate(problems):
         # problem = ProblemService.load(problem_folder, load_testcase=True)
         problem = ProblemService.load_v1(problem_folder, load_testcase=True, translations=['vi'])
-        print(i + 1, problem.name)
-        prob_id = ucode.create_problem(lesson_id=lesson_id, problem=problem, xp=-1)
-        print(f"Problem uploaded with id #{prob_id}")
+        print(i + 1, problem.name, "testcases:", len(problem.testcases))
+        # prob_id = ucode.create_problem(lesson_id=lesson_id, problem=problem, xp=-1)
+        # print(f"Problem uploaded with id #{prob_id}")
 
     print("Total problems:", len(problems))
 
@@ -527,9 +529,10 @@ def create_problems_to_lesson_ucode_live():
 def reupload_testcases():
     ucode = UCode("prod")
     problem_folder = "D:\\projects\\ucode\\dsa-thematic-problems\\de_thi_hsg\\hanoi_2020_2021_thcs\\p4_itable"
+    # problem_folder = "D:\\projects\\ucode\\dsa-thematic-problems\\de_thi_hsg\\vinhphuc_2020_2021_thcs\\p3_weightloss"
     problem: Problem = ProblemService.load(problem_folder, load_testcase=True)
 
-    question_id = 45486
+    question_id = 45490
     ucode.upload_testcases(question_id, ProblemService.join_testcases(problem))
     #
     print(len(problem.testcases))
